@@ -25,8 +25,11 @@
 #define _GVMD_MANAGE_H
 
 #include "iterator.h"
+#include "manage_alerts.h"
 #include "manage_configs.h"
+#include "manage_events.h"
 #include "manage_get.h"
+#include "sql.h"
 #include "utils.h"
 
 #include <stdio.h>
@@ -41,15 +44,9 @@
 #include <gvm/util/authutils.h>
 #include <gvm/osp/osp.h>
 
-/**
- * @brief Data structure for info used to connect to the database
- */
-typedef struct {
-  gchar *name; ///< The database name
-  gchar *host; ///< The database host or socket directory
-  gchar *port; ///< The database port or socket file extension
-  gchar *user; ///< The database user name
-} db_conn_info_t;
+#if OPENVASD
+#include <gvm/openvasd/openvasd.h>
+#endif
 
 /**
  * @brief OID of ping_host.nasl
@@ -127,7 +124,7 @@ init_manage (GSList*, const db_conn_info_t *, int, int, int, int,
              manage_connection_forker_t, int);
 
 int
-init_manage_helper (GSList *, const db_conn_info_t *, int);
+init_manage_helper (GSList *, const db_conn_info_t *, int, int);
 
 void
 init_manage_process (const db_conn_info_t*);
@@ -144,6 +141,8 @@ manage_reset_currents ();
 
 /* Commands. */
 
+#define MAX_LOCK_RETRIES 16
+
 /**
  * @brief A command.
  */
@@ -328,14 +327,17 @@ typedef enum scanner_type
   SCANNER_TYPE_CVE = 3,
   /* 4 was removed (SCANNER_TYPE_GMP). */
   SCANNER_TYPE_OSP_SENSOR = 5,
-  SCANNER_TYPE_MAX = 6,
+  SCANNER_TYPE_OPENVASD = 6,
+  SCANNER_TYPE_MAX = 7,
 } scanner_type_t;
 
 int
 scanner_type_valid (scanner_type_t);
 
+int
+scanner_type_supports_unix_sockets (scanner_type_t);
+
 typedef resource_t credential_t;
-typedef resource_t alert_t;
 typedef resource_t filter_t;
 typedef resource_t group_t;
 typedef resource_t host_t;
@@ -419,22 +421,6 @@ set_resource_id_deprecated (const char *, const char *, gboolean);
 
 /* Events and Alerts. */
 
-/**
- * @brief Data about a report sent by an alert.
- */
-typedef struct {
-  gchar *local_filename;          ///< Path to the local report file.
-  gchar *remote_filename;         ///< Path or filename to send to / as.
-  gchar *content_type;            ///< The MIME content type of the report.
-  gchar *report_format_name;      ///< Name of the report format used.
-} alert_report_data_t;
-
-void
-alert_report_data_free (alert_report_data_t *);
-
-void
-alert_report_data_reset (alert_report_data_t *);
-
 /**
  * @brief Default format string for alert email, when including report.
  */
@@ -537,53 +523,6 @@ alert_report_data_reset (alert_report_data_t *);
  "Please contact your local system administrator if you think it\n"           \
  "was created or assigned erroneously.\n"
 
-/**
- * @brief Types of task events.
- */
-typedef enum
-{
-  EVENT_ERROR,
-  EVENT_TASK_RUN_STATUS_CHANGED,
-  EVENT_NEW_SECINFO,
-  EVENT_UPDATED_SECINFO,
-  EVENT_TICKET_RECEIVED,
-  EVENT_ASSIGNED_TICKET_CHANGED,
-  EVENT_OWNED_TICKET_CHANGED
-} event_t;
-
-/**
- * @brief Types of alerts.
- */
-typedef enum
-{
-  ALERT_METHOD_ERROR,
-  ALERT_METHOD_EMAIL,
-  ALERT_METHOD_HTTP_GET,
-  ALERT_METHOD_SOURCEFIRE,
-  ALERT_METHOD_START_TASK,
-  ALERT_METHOD_SYSLOG,
-  ALERT_METHOD_VERINICE,
-  ALERT_METHOD_SEND,
-  ALERT_METHOD_SCP,
-  ALERT_METHOD_SNMP,
-  ALERT_METHOD_SMB,
-  ALERT_METHOD_TIPPINGPOINT,
-  ALERT_METHOD_VFIRE,
-} alert_method_t;
-
-/**
- * @brief Types of alert conditions.
- */
-typedef enum
-{
-  ALERT_CONDITION_ERROR,
-  ALERT_CONDITION_ALWAYS,
-  ALERT_CONDITION_SEVERITY_AT_LEAST,
-  ALERT_CONDITION_SEVERITY_CHANGED,
-  ALERT_CONDITION_FILTER_COUNT_AT_LEAST,
-  ALERT_CONDITION_FILTER_COUNT_CHANGED
-} alert_condition_t;
-
 int
 manage_check_alerts (GSList *, const db_conn_info_t *);
 
@@ -609,9 +548,6 @@ alert_uuid (alert_t);
 gboolean
 find_alert_with_permission (const char *, alert_t *, const char *);
 
-int
-manage_alert (const char *, const char *, event_t, const void*, gchar **);
-
 int
 manage_test_alert (const char *, gchar **);
 
@@ -657,33 +593,9 @@ alert_iterator_filter_readable (iterator_t*);
 int
 alert_iterator_active (iterator_t*);
 
-const char*
-alert_condition_name (alert_condition_t);
-
-gchar*
-alert_condition_description (alert_condition_t, alert_t);
-
-const char*
-event_name (event_t);
-
-gchar*
-event_description (event_t, const void *, const char *);
-
 alert_method_t
 alert_method (alert_t alert);
 
-const char*
-alert_method_name (alert_method_t);
-
-alert_condition_t
-alert_condition_from_name (const char*);
-
-event_t
-event_from_name (const char*);
-
-alert_method_t
-alert_method_from_name (const char*);
-
 void
 init_alert_data_iterator (iterator_t *, alert_t, int, const char *);
 
@@ -902,9 +814,8 @@ int
 task_last_report (task_t, report_t*);
 
 const char *
-task_iterator_trend_counts (iterator_t *, int, int, int, double, int, int, int,
-                            double);
-
+task_iterator_trend_counts (iterator_t *, int, int, int, int, double, int, int,
+                            int, int, double);
 int
 task_schedule_periods (task_t);
 
@@ -1065,9 +976,15 @@ severity_data_add (severity_data_t*, double);
 void
 severity_data_add_count (severity_data_t*, double, int);
 
+#if CVSS3_RATINGS == 1
+void
+severity_data_level_counts (const severity_data_t*,
+                            int*, int*, int*, int*, int*, int*, int*);
+#else
 void
 severity_data_level_counts (const severity_data_t*,
                             int*, int*, int*, int*, int*, int*);
+#endif
 
 
 /* General task facilities. */
@@ -1120,12 +1037,15 @@ user_has_super (const char *, user_t);
   " 'FortiOS Local Security Checks',"              \
   " 'FreeBSD Local Security Checks',"              \
   " 'Gentoo Local Security Checks',"               \
+  " 'HCE Local Security Checks',"                  \
   " 'HP-UX Local Security Checks',"                \
   " 'Huawei EulerOS Local Security Checks',"       \
   " 'JunOS Local Security Checks',"                \
   " 'Mac OS X Local Security Checks',"             \
   " 'Mageia Linux Local Security Checks',"         \
   " 'Mandrake Local Security Checks',"             \
+  " 'openEuler Local Security Checks',"            \
+  " 'openSUSE Local Security Checks',"             \
   " 'Oracle Linux Local Security Checks',"         \
   " 'Palo Alto PAN-OS Local Security Checks',"     \
   " 'Red Hat Local Security Checks',"              \
@@ -1135,7 +1055,8 @@ user_has_super (const char *, user_t);
   " 'SuSE Local Security Checks',"                 \
   " 'VMware Local Security Checks',"               \
   " 'Ubuntu Local Security Checks',"               \
-  " 'Windows : Microsoft Bulletins'"
+  " 'Windows : Microsoft Bulletins',"              \
+  " 'Windows Local Security Checks'"
 
 /**
  * @brief Whole only families.
@@ -1149,10 +1070,13 @@ user_has_super (const char *, user_t);
     "Fedora Local Security Checks",                \
     "FreeBSD Local Security Checks",               \
     "Gentoo Local Security Checks",                \
+    "HCE Local Security Checks",                   \
     "HP-UX Local Security Checks",                 \
     "Huawei EulerOS Local Security Checks",        \
     "Mageia Linux Local Security Checks",          \
     "Mandrake Local Security Checks",              \
+    "openEuler Local Security Checks",             \
+    "openSUSE Local Security Checks",              \
     "Oracle Linux Local Security Checks",          \
     "Red Hat Local Security Checks",               \
     "Rocky Linux Local Security Checks",           \
@@ -1160,6 +1084,7 @@ user_has_super (const char *, user_t);
     "Solaris Local Security Checks",               \
     "SuSE Local Security Checks",                  \
     "Ubuntu Local Security Checks",                \
+    "Windows Local Security Checks",               \
     NULL }
 
 gboolean
@@ -1337,6 +1262,15 @@ int
 report_scan_result_count (report_t, const char*, const char*, int, const char*,
                           const char*, int, int, int*);
 
+#if CVSS3_RATINGS == 1
+int
+report_counts (const char*, int*, int*, int*, int*, int*, int*, double*,
+               int, int);
+
+int
+report_counts_id (report_t, int*, int*, int*, int*, int*, int*, double*,
+                  const get_data_t*, const char*);
+#else
 int
 report_counts (const char*, int*, int*, int*, int*, int*, double*,
                int, int);
@@ -1344,6 +1278,7 @@ report_counts (const char*, int*, int*, int*, int*, int*, double*,
 int
 report_counts_id (report_t, int*, int*, int*, int*, int*, double*,
                   const get_data_t*, const char*);
+#endif
 
 int
 report_counts_id_no_filt (report_t, int*, int*, int*, int*, int*, int*,
@@ -1416,7 +1351,7 @@ int
 init_result_get_iterator (iterator_t*, const get_data_t *, report_t,
                           const char*, const gchar *);
 int
-init_result_get_iterator_all (iterator_t* iterator, get_data_t *get);                         
+init_result_get_iterator_all (iterator_t* iterator, get_data_t *get);
 
 gboolean
 next_report (iterator_t*, report_t*);
@@ -1688,7 +1623,82 @@ void
 init_app_locations_iterator (iterator_t*, report_host_t, const gchar *);
 
 const char *
-app_locations_iterator_location (iterator_t *);
+app_locations_iterator_location (iterator_t*);
+
+void
+init_cpe_match_nodes_iterator (iterator_t*, const char *);
+
+void
+init_cve_cpe_match_nodes_iterator (iterator_t*, const char *);
+
+void
+init_cve_reference_iterator (iterator_t*, const char *);
+
+const char*
+cve_reference_iterator_url (iterator_t*);
+
+const char*
+cve_reference_iterator_tags (iterator_t*);
+
+const char*
+cve_reference_iterator_tags_count (iterator_t*);
+
+long long int
+cpe_match_nodes_iterator_root_id (iterator_t*);
+
+void
+init_host_details_cpe_iterator (iterator_t*, report_host_t);
+
+const char*
+host_details_cpe_iterator_cpe (iterator_t*);
+
+void
+init_cpe_match_node_childs_iterator (iterator_t*, long long int);
+
+long long int
+cpe_match_node_childs_iterator_id (iterator_t*);
+
+void
+init_cpe_match_string_iterator (iterator_t*, long long int);
+
+const char*
+cpe_match_string_iterator_criteria (iterator_t*);
+
+const char*
+cpe_match_string_iterator_match_criteria_id (iterator_t*);
+
+const char*
+cpe_match_string_iterator_status (iterator_t*);
+
+const char*
+cpe_match_string_iterator_version_start_incl (iterator_t*);
+
+const char*
+cpe_match_string_iterator_version_start_excl (iterator_t*);
+
+const char*
+cpe_match_string_iterator_version_end_incl (iterator_t*);
+
+const char*
+cpe_match_string_iterator_version_end_excl (iterator_t*);
+
+int
+cpe_match_string_iterator_vulnerable (iterator_t*);
+
+void
+init_cpe_match_string_matches_iterator (iterator_t*, const char *, const char*);
+
+const char*
+cpe_matches_cpe_name_id (iterator_t*);
+
+const char*
+cpe_matches_cpe_name (iterator_t*);
+
+void
+init_host_details_cpe_product_iterator (iterator_t*, const char *, report_host_t);
+
+const char*
+host_details_cpe_product_iterator_value (iterator_t*);
 
 void
 init_host_prognosis_iterator (iterator_t*, report_host_t);
@@ -1733,7 +1743,7 @@ manage_filter_controls (const gchar *, int *, int *, gchar **, int *);
 
 void
 manage_report_filter_controls (const gchar *, int *, int *, gchar **, int *,
-                               int *, gchar **, gchar **, gchar **, gchar **, 
+                               int *, gchar **, gchar **, gchar **, gchar **,
                                gchar **, int *, int *, int *, int *, gchar **);
 
 gchar *
@@ -1751,7 +1761,8 @@ find_target_with_permission (const char *, target_t *, const char *);
 int
 create_target (const char*, const char*, const char*, const char*, const char*,
                const char *, const char*, credential_t, credential_t,
-               const char *, credential_t, credential_t, credential_t,
+               const char *,
+               credential_t, credential_t, credential_t, credential_t,
                const char *, const char *, const char *, const char *,
                target_t*);
 
@@ -1762,7 +1773,7 @@ int
 modify_target (const char*, const char*, const char*, const char*, const char*,
                const char*, const char*, const char*, const char*, const char*,
                const char*, const char*, const char*, const char*, const char*,
-               const char*);
+               const char*, const char*);
 
 int
 delete_target (const char*, int);
@@ -1812,6 +1823,9 @@ target_iterator_snmp_credential (iterator_t*);
 int
 target_iterator_ssh_elevate_credential (iterator_t*);
 
+int
+target_iterator_krb5_credential (iterator_t*);
+
 int
 target_iterator_ssh_trash (iterator_t*);
 
@@ -1827,6 +1841,9 @@ target_iterator_snmp_trash (iterator_t*);
 int
 target_iterator_ssh_elevate_trash (iterator_t*);
 
+int
+target_iterator_krb5_trash (iterator_t*);
+
 const char*
 target_iterator_allow_simultaneous_ips (iterator_t*);
 
@@ -2116,7 +2133,7 @@ void
 manage_nvt_preferences_enable ();
 
 void
-init_nvt_preference_iterator (iterator_t*, const char*);
+init_nvt_preference_iterator (iterator_t*, const char*, gboolean);
 
 const char*
 nvt_preference_iterator_name (iterator_t*);
@@ -2218,7 +2235,7 @@ int
 create_credential (const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
-                   const char*, credential_t*);
+                   const char*, const char*, const char*, credential_t*);
 
 int
 copy_credential (const char*, const char*, const char*,
@@ -2228,7 +2245,7 @@ int
 modify_credential (const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
                    const char*, const char*, const char*, const char*,
-                   const char*);
+                   const char*, const char*, const char*);
 
 int
 delete_credential (const char *, int);
@@ -2269,6 +2286,12 @@ credential_iterator_privacy_password (iterator_t*);
 const char*
 credential_iterator_public_key (iterator_t*);
 
+const char*
+credential_iterator_kdc (iterator_t*);
+
+const char*
+credential_iterator_realm (iterator_t*);
+
 const char*
 credential_iterator_private_key (iterator_t*);
 
@@ -2589,7 +2612,7 @@ init_override_iterator (iterator_t*, const get_data_t*, nvt_t, result_t,
                         task_t);
 
 int
-init_override_iterator_all (iterator_t* iterator, get_data_t *get);                        
+init_override_iterator_all (iterator_t* iterator, get_data_t *get);
 
 const char*
 override_iterator_nvt_oid (iterator_t*);
@@ -2682,12 +2705,14 @@ manage_system_report (const char *, const char *, const char *, const char *,
 int
 manage_create_scanner (GSList *, const db_conn_info_t *, const char *,
                        const char *, const char *, const char *, const char *,
-                       const char *, const char *, const char *);
+                       const char *, const char *, const char *,
+                       const char *, const char *);
 
 int
 manage_modify_scanner (GSList *, const db_conn_info_t *, const char *,
                        const char *, const char *, const char *, const char *,
-                       const char *, const char *, const char *, const char *);
+                       const char *, const char *, const char *, const char *,
+                       const char *, const char *);
 
 int
 manage_delete_scanner (GSList *, const db_conn_info_t *, const gchar *);
@@ -2698,16 +2723,53 @@ manage_verify_scanner (GSList *, const db_conn_info_t *, const gchar *);
 int
 manage_get_scanners (GSList *, const db_conn_info_t *);
 
-int
+
+typedef enum {
+  CREATE_SCANNER_INTERNAL_ERROR = -1,     ///< Internal error
+  CREATE_SCANNER_SUCCESS = 0,             ///< Success
+  CREATE_SCANNER_ALREADY_EXISTS,          ///< Scanner already exists
+  CREATE_SCANNER_MISSING_TYPE,            ///< Missing type
+  CREATE_SCANNER_MISSING_HOST,            ///< Missing host
+  CREATE_SCANNER_CREDENTIAL_NOT_FOUND,    ///< Credential not found
+  CREATE_SCANNER_CREDENTIAL_NOT_CC,       ///< Credential must have type "cc"
+  CREATE_SCANNER_INVALID_TYPE,            ///< Invalid type
+  CREATE_SCANNER_INVALID_PORT,            ///< Invalid port
+  CREATE_SCANNER_INVALID_HOST,            ///< Invalid host
+  CREATE_SCANNER_INVALID_RELAY_PORT,      ///< Invalid relay port
+  CREATE_SCANNER_INVALID_RELAY_HOST,      ///< Invalid relay host
+  CREATE_SCANNER_UNIX_SOCKET_UNSUPPORTED, ///< Type doesn't support UNIX sockets
+  CREATE_SCANNER_PERMISSION_DENIED = 99   ///< Permission denied
+} create_scanner_return_t;
+
+create_scanner_return_t
 create_scanner (const char*, const char *, const char *, const char *,
-                const char *, scanner_t *, const char *, const char *);
+                const char *, scanner_t *, const char *, const char *,
+                const char *, const char *);
 
 int
 copy_scanner (const char*, const char*, const char *, scanner_t *);
 
-int
+typedef enum {
+  MODIFY_SCANNER_INTERNAL_ERROR = -1,     ///< Internal error
+  MODIFY_SCANNER_SUCCESS = 0,             ///< Success
+  MODIFY_SCANNER_ALREADY_EXISTS,          ///< Scanner already exists
+  MODIFY_SCANNER_MISSING_ID,              ///< Missing scanner id
+  MODIFY_SCANNER_NOT_FOUND,               ///< Scanner not found
+  MODIFY_SCANNER_CREDENTIAL_NOT_FOUND,    ///< Credential not found
+  MODIFY_SCANNER_CREDENTIAL_NOT_CC,       ///< Credential must have type "cc"
+  MODIFY_SCANNER_INVALID_TYPE,            ///< Invalid type
+  MODIFY_SCANNER_INVALID_PORT,            ///< Invalid port
+  MODIFY_SCANNER_INVALID_HOST,            ///< Invalid host
+  MODIFY_SCANNER_INVALID_RELAY_PORT,      ///< Invalid relay port
+  MODIFY_SCANNER_INVALID_RELAY_HOST,      ///< Invalid relay host
+  MODIFY_SCANNER_UNIX_SOCKET_UNSUPPORTED, ///< Type doesn't support UNIX sockets
+  MODIFY_SCANNER_PERMISSION_DENIED = 99   ///< Permission denied
+} modify_scanner_return_t;
+
+modify_scanner_return_t
 modify_scanner (const char*, const char*, const char*, const char *,
-                const char *, const char *, const char *, const char *);
+                const char *, const char *, const char *, const char *,
+                const char *, const char *);
 
 int
 delete_scanner (const char *, int);
@@ -2733,11 +2795,14 @@ scanner_writable (scanner_t);
 const char *
 scanner_uuid_default ();
 
+gboolean
+scanner_has_relay (scanner_t);
+
 char *
-scanner_host (scanner_t);
+scanner_host (scanner_t, gboolean);
 
 int
-scanner_port (scanner_t);
+scanner_port (scanner_t, gboolean);
 
 int
 scanner_type (scanner_t);
@@ -2793,6 +2858,12 @@ scanner_iterator_key_pub (iterator_t *);
 const char*
 scanner_iterator_credential_type (iterator_t *);
 
+const char*
+scanner_iterator_relay_host (iterator_t *);
+
+int
+scanner_iterator_relay_port (iterator_t *);
+
 int
 scanner_config_iterator_readable (iterator_t *);
 
@@ -2832,7 +2903,8 @@ osp_connect_with_data (const char *,
                        int,
                        const char *,
                        const char *,
-                       const char *);
+                       const char *,
+                       gboolean);
 
 osp_connection_t *
 osp_scanner_connect (scanner_t);
@@ -3339,6 +3411,12 @@ manage_scap_update_time ();
 
 /* CPE. */
 
+void
+init_cpe_deprecated_by_iterator (iterator_t *, const char *);
+
+const char *
+cpe_deprecated_by_iterator_deprecated_by (iterator_t *);
+
 void
 init_cpe_cve_iterator (iterator_t *, const char *, int, const char *);
 
@@ -3355,23 +3433,30 @@ const char*
 cpe_info_iterator_title (iterator_t*);
 
 const char*
-cpe_info_iterator_status (iterator_t*);
+cpe_info_iterator_deprecated (iterator_t*);
 
 const char *
 cpe_info_iterator_severity (iterator_t*);
 
-const char*
-cpe_info_iterator_deprecated_by_id (iterator_t*);
-
 const char*
 cpe_info_iterator_cve_refs (iterator_t*);
 
 const char*
-cpe_info_iterator_nvd_id (iterator_t*);
+cpe_info_iterator_cpe_name_id (iterator_t*);
 
 gchar *
 cpe_details_xml (const char*);
 
+void
+init_cpe_reference_iterator (iterator_t *, const char *);
+
+const char*
+cpe_reference_iterator_href (iterator_t *);
+
+const char*
+cpe_reference_iterator_type (iterator_t *);
+
+
 /* CVE. */
 
 const char*
@@ -3934,9 +4019,6 @@ nvts_feed_info (gchar **, gchar **, gchar **, gchar **);
 int
 nvts_check_feed (int *, int *, gchar **);
 
-int
-manage_update_nvts_osp (const gchar *);
-
 int
 manage_rebuild (GSList *, const db_conn_info_t *);
 
@@ -3989,4 +4071,11 @@ get_vt_verification_collation ();
 void
 set_vt_verification_collation (const char *);
 
+#if OPENVASD
+
+/* openvasd Connection */
+openvasd_connector_t
+openvasd_scanner_connect (scanner_t, const char *);
+#endif
+
 #endif /* not _GVMD_MANAGE_H */
