@@ -156,18 +156,6 @@ int
 manage_set_config_families (config_t, GPtrArray*, GPtrArray*, GPtrArray*, int,
                             gchar **);
 
-void
-init_config_timeout_iterator (iterator_t*, config_t);
-
-const char*
-config_timeout_iterator_oid (iterator_t *);
-
-const char*
-config_timeout_iterator_nvt_name (iterator_t *);
-
-const char*
-config_timeout_iterator_value (iterator_t *);
-
 gboolean
 configs_feed_dir_exists ();
 
