@@ -3218,6 +3218,135 @@ migrate_255_to_256 ()
   return 0;
 }
 
+/**
+ * @brief Migrate the database from version 256 to version 257.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_256_to_257 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 256. */
+
+  if (manage_db_version () != 256)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Add new columns
+
+  sql ("ALTER TABLE report_formats ADD COLUMN"
+       " report_type text DEFAULT 'all';");
+
+  sql ("ALTER TABLE report_formats_trash ADD COLUMN"
+       " report_type text DEFAULT 'all';");
+
+  /* Set the database version to 257. */
+
+  set_db_version (257);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 257 to version 258.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_257_to_258 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 257. */
+
+  if (manage_db_version () != 257)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Change timeout config preferences to normal VT preferences
+
+  sql ("UPDATE config_preferences SET"
+       " type = 'PLUGINS_PREFS',"
+       " name = substring(name, 9) || ':0:entry:timeout',"
+       " pref_nvt = substring(name, 9),"
+       " pref_id = 0,"
+       " pref_type = 'entry',"
+       " pref_name = 'timeout'"
+       " WHERE name LIKE 'timeout.%%' AND type = 'SERVER_PREFS';");
+
+
+  sql ("UPDATE config_preferences_trash SET"
+       " type = 'PLUGINS_PREFS',"
+       " name = substring(name, 9) || ':0:entry:timeout',"
+       " pref_nvt = substring(name, 9),"
+       " pref_id = 0,"
+       " pref_type = 'entry',"
+       " pref_name = 'timeout'"
+       " WHERE name LIKE 'timeout.%%' AND type = 'SERVER_PREFS';");
+
+  /* Set the database version to 258. */
+
+  set_db_version (258);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 258 to version 259.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_258_to_259 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 258. */
+
+  if (manage_db_version () != 258)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  // Add relay_host and relay_port fields to scanners
+
+  sql ("ALTER TABLE scanners ADD COLUMN relay_host text;"); 
+  sql ("ALTER TABLE scanners ADD COLUMN relay_port integer;"); 
+
+  sql ("ALTER TABLE scanners_trash ADD COLUMN relay_host text;"); 
+  sql ("ALTER TABLE scanners_trash ADD COLUMN relay_port integer;");
+ 
+  // Set base values for new relay fields
+
+  sql ("UPDATE scanners SET relay_host = '', relay_port = 0;");
+  sql ("UPDATE scanners_trash SET relay_host = '', relay_port = 0;");
+
+  /* Set the database version to 259. */
+
+  set_db_version (259);
+
+  sql_commit ();
+
+  return 0;
+}
+
 #undef UPDATE_DASHBOARD_SETTINGS
 
 /**
@@ -3280,6 +3409,9 @@ static migrator_t database_migrators[] = {
   {254, migrate_253_to_254},
   {255, migrate_254_to_255},
   {256, migrate_255_to_256},
+  {257, migrate_256_to_257},
+  {258, migrate_257_to_258},
+  {259, migrate_258_to_259},
   /* End marker. */
   {-1, NULL}};
 
