@@ -25,6 +25,7 @@
 #define _GVMD_MANAGE_SQL_H
 
 #include <gvm/util/xmlutils.h>
+#include <time.h>
 
 #include "manage.h"
 #include "manage_utils.h"
@@ -97,25 +98,35 @@
  */
 #define SCANNER_UUID_DEFAULT "08b69003-5fc2-4037-a479-93b440211c73"
 
+/**
+ * @brief UUID of 'openvasd Default' scanner.
+ */
+#define SCANNER_UUID_OPENVASD_DEFAULT "8154d8e3-30ee-4959-9151-1863c89a8e62"
+
 /**
  * @brief UUID of 'CVE' scanner.
  */
 #define SCANNER_UUID_CVE "6acd0832-df90-11e4-b9d5-28d24461215b"
 
 /**
- * @brief UUID of 'Rows Per Page' setting.
+ * @brief UUID of setting.
  */
-#define SETTING_UUID_ROWS_PER_PAGE "5f5a8712-8017-11e1-8556-406186ea4fc5"
+#define SETTING_UUID_AUTO_CACHE_REBUILD "a09285b0-2d47-49b6-a4ef-946ee71f1d5c"
 
 /**
- * @brief UUID of 'Max Rows Per Page' setting.
+ * @brief UUID of setting.
  */
-#define SETTING_UUID_MAX_ROWS_PER_PAGE "76374a7a-0569-11e6-b6da-28d24461215b"
+#define SETTING_UUID_AUTO_REFRESH "578a1c14-e2dc-45ef-a591-89d31391d007"
 
 /**
- * @brief UUID of 'Note/Override Excerpt Size' setting.
+ * @brief UUID of 'CVE-CPE Matching Version' setting.
  */
-#define SETTING_UUID_EXCERPT_SIZE "9246a0f6-c6ad-44bc-86c2-557a527c8fb3"
+#define SETTING_UUID_CVE_CPE_MATCHING_VERSION "2e8a8ccc-219f-4a82-824a-3ad88b6d4029"
+
+/**
+ * @brief UUID of setting.
+ */
+#define SETTING_UUID_DEFAULT_SEVERITY "7eda49c5-096c-4bef-b1ab-d080d87300df"
 
 /**
  * @brief UUID of 'Default CA Cert' setting.
@@ -123,9 +134,14 @@
 #define SETTING_UUID_DEFAULT_CA_CERT "9ac801ea-39f8-11e6-bbaa-28d24461215b"
 
 /**
- * @brief UUID of 'Debian LSC Package Maintainer' setting.
+ * @brief UUID of setting.
  */
-#define SETTING_UUID_LSC_DEB_MAINTAINER "2fcbeac8-4237-438f-b52a-540a23e7af97"
+#define SETTING_UUID_DYNAMIC_SEVERITY "77ec2444-e7f2-4a80-a59b-f4237782d93f"
+
+/**
+ * @brief UUID of 'Note/Override Excerpt Size' setting.
+ */
+#define SETTING_UUID_EXCERPT_SIZE "9246a0f6-c6ad-44bc-86c2-557a527c8fb3"
 
 /**
  * @brief UUID of 'Feed Import Owner' setting.
@@ -138,25 +154,55 @@
 #define SETTING_UUID_FEED_IMPORT_ROLES "ff000362-338f-11ea-9051-28d24461215b"
 
 /**
- * @brief UUID of 'Delta Reports Version' setting.
+ * @brief UUID of setting.
  */
-#define SETTING_UUID_DELTA_REPORTS_VERSION "985a0c05-2140-4e66-9989-ce9a0906a5a9"
+#define SETTING_UUID_FILE_DETAILS "a6ac88c5-729c-41ba-ac0a-deea4a3441f2"
+
+/**
+ * @brief UUID of setting.
+ */
+#define SETTING_UUID_FILE_LIST "0872a6ed-4f85-48c5-ac3f-a5ef5e006745"
+
+/**
+ * @brief UUID of setting.
+ */
+#define SETTING_UUID_FILE_REPORT "e1a2ae0b-736e-4484-b029-330c9e15b900"
+
+/**
+ * @brief UUID of 'Debian LSC Package Maintainer' setting.
+ */
+#define SETTING_UUID_LSC_DEB_MAINTAINER "2fcbeac8-4237-438f-b52a-540a23e7af97"
+
+/**
+ * @brief UUID of 'Max Rows Per Page' setting.
+ */
+#define SETTING_UUID_MAX_ROWS_PER_PAGE "76374a7a-0569-11e6-b6da-28d24461215b"
+
+/**
+ * @brief UUID of setting.
+ */
+#define SETTING_UUID_PREFERRED_LANG "6765549a-934e-11e3-b358-406186ea4fc5"
+
+/**
+ * @brief UUID of 'Rows Per Page' setting.
+ */
+#define SETTING_UUID_ROWS_PER_PAGE "5f5a8712-8017-11e1-8556-406186ea4fc5"
 
 /**
  * @brief UUID of 'SecInfo SQL Buffer Threshold' setting.
  */
 #define SETTING_UUID_SECINFO_SQL_BUFFER_THRESHOLD "316275a9-3629-49ad-9cea-5b3ab155b93f"
 
-/**
- * @brief UUID of 'User Interface Time Format' setting.
- */
-#define SETTING_UUID_USER_INTERFACE_TIME_FORMAT "11deb7ff-550b-4950-aacf-06faeb7c61b9"
-
 /**
  * @brief UUID of 'User Interface Date Format' setting.
  */
 #define SETTING_UUID_USER_INTERFACE_DATE_FORMAT "d9857b7c-1159-4193-9bc0-18fae5473a69"
 
+/**
+ * @brief UUID of 'User Interface Time Format' setting.
+ */
+#define SETTING_UUID_USER_INTERFACE_TIME_FORMAT "11deb7ff-550b-4950-aacf-06faeb7c61b9"
+
 /**
  * @brief Trust constant for error.
  */
@@ -358,6 +404,7 @@ credential_t target_ssh_credential (target_t);
 credential_t target_smb_credential (target_t);
 credential_t target_esxi_credential (target_t);
 credential_t target_ssh_elevate_credential (target_t);
+credential_t target_krb5_credential (target_t);
 
 int create_current_report (task_t, char **, task_status_t);
 
@@ -442,6 +489,8 @@ init_get_iterator (iterator_t*, const char *, const get_data_t *, column_t *,
                    column_t *, const char **, int, const char *, const char *,
                    int);
 
+int openvasd_get_details_from_iterator (iterator_t *, char **, GSList **);
+
 gchar *
 columns_build_select (column_t *);
 
@@ -453,7 +502,7 @@ void
 check_alerts ();
 
 int
-manage_option_setup (GSList *, const db_conn_info_t *);
+manage_option_setup (GSList *, const db_conn_info_t *, int);
 
 void
 manage_option_cleanup ();
@@ -461,8 +510,39 @@ manage_option_cleanup ();
 void
 update_all_config_caches ();
 
+int
+escalate_2 (alert_t alert, task_t task, report_t report, event_t event,
+            const void* event_data, alert_method_t method,
+            alert_condition_t condition,
+            const get_data_t *get, int notes_details, int overrides_details,
+            gchar **script_message);
+
 void
-event (event_t, void *, resource_t, resource_t);
+init_event_alert_iterator (iterator_t *, event_t);
+
+alert_t
+event_alert_iterator_alert (iterator_t *);
+
+int
+event_alert_iterator_active (iterator_t *);
+
+user_t
+alert_owner (alert_t);
+
+alert_condition_t
+alert_condition (alert_t);
+
+int
+alert_applies_to_task (alert_t, task_t);
+
+time_t
+alert_secinfo_count (alert_t, char *);
+
+int
+task_second_last_report (task_t, report_t *);
+
+double
+task_severity_double (task_t, int, int, int);
 
 gboolean
 find_trash (const char *, const char *, resource_t *);
@@ -542,4 +622,22 @@ cleanup_nvt_sequences ();
 int
 cleanup_ids_for_table (const char *);
 
+void
+
+create_indexes_cpe ();
+
+void
+drop_indexes_cpe ();
+
+void
+create_indexes_cve ();
+
+void
+drop_indexes_cve ();
+
+#if OPENVASD
+void
+parse_openvasd_report (task_t, report_t, GSList *, time_t, time_t);
+#endif
+
 #endif /* not _GVMD_MANAGE_SQL_H */
