@@ -277,7 +277,7 @@ ticket_count (const get_data_t *get)
  *         -1 error.
  */
 int
-init_ticket_iterator (iterator_t *iterator, const get_data_t *get)
+init_ticket_iterator (iterator_t *iterator, get_data_t *get)
 {
   static const char *filter_columns[] = TICKET_ITERATOR_FILTER_COLUMNS;
   static column_t columns[] = TICKET_ITERATOR_COLUMNS;
