@@ -25,10 +25,20 @@
 #define _GVMD_SQL_H
 
 #include "iterator.h"
-#include "manage.h"
 
 #include <glib.h>
 
+/**
+ * @brief Data structure for info used to connect to the database
+ */
+typedef struct
+{
+  gchar *name; ///< The database name
+  gchar *host; ///< The database host or socket directory
+  gchar *port; ///< The database port or socket file extension
+  gchar *user; ///< The database user name
+} db_conn_info_t;
+
 /* Helpers. */
 
 const char *
@@ -167,4 +177,13 @@ iterator_column_name (iterator_t *, int);
 int
 iterator_column_count (iterator_t *);
 
+int
+sql_copy_write_str (const char *, int);
+
+int
+sql_copy_end ();
+
+gchar *
+sql_copy_escape (const char *);
+
 #endif /* not _GVMD_SQL_H */
